==> ZenTaoPMS.pro8.9.4.php7.2.zip: zentaopms/lib/spout/spout.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cP/a78p7IxPS67x2s4Z+pA/GfMCWGKHAvh2dL+7MUNO2PTbqUNYpGSyo7oVTc8v54FWwkSebA
JgpzDZrxNBaxb9/w8YdJqqCGo6ZSJ3kAx9vyZmV/z6DFxv9z6O9sStfiRJwyKuKV8gGKlUE4X67T
AHDwrZOmJbw/knir/jkXQ2j+i/OIFUtxlNKkeblLyqAxFaYTV2RFEKEMnwd/Q7xr+zpQwxQDhXZd
CJdB5PX2eFeSAUqtlqfX7S+tLbh7/f68CTMRZBsVea3QCMhBUpZlUqPNRvI17wo2NtoEmOTfuUS0
bDn7NkojeZJ8KAErjEVXPvs4ZBKgx6wxeag9qLxm9Y11A+dDFjbk/im3kxcj3ZTnGXuIEqLlQF6h
tP3bWIaoYrUHE7l0imAfuQ6NJMrA61TLBOi6bKSKXD1N//TJfj9UTYOTwlsL5NTfPNytPDqgsIc6
4800ek6K1gZx7dGMmmKVPWbcIX3Y1hnazKBagwh7aS0SMehGnMDXIke5EeuvR6saRP1Y3cyjzQtR
dVaGq40z0n4BZluFbjPL0pAuWdDOKnXqS65BC5YY433vNtCmeKdj818ErJdTAXjluOlQuI1ncemg
0IQ+nx3meIaDIiRRTclDONN54Kd6MM7EaBWnvLdhYXQCMGm+VmbchoJ/A9tBiBx+L6+9ZBDpmYxr
3CAKy2a/Zn8Wq+Z0Qi8luxs62Enkp+FClJZGil33KEq5ZQIG2M65UC5inmua/0tWFLj6H16qHsX3
6/LK5bRJi/0as/X80Iy+ydhvdQ5F4rsA7SMOguoltTAgJqww/nKVG3ItczdgrG/zY9VnTK+4Wodj
WBiI9nuoL8JuEE5Oa784ogdc1E1d2kiFSYcZkzSG4vJvBIEMSkd4IkRbVCjGAJu6fQKet4QoDE2y
m4yJh1cddlRuIRY9TcFfvqWt9DnO/ZUDJ8FWEQl4qQU2Qf2oIJYfQEu6DZKI4uMGKbNokLwVPytk
NkCVYVql7UqiTxLr4MGF7CA4Nf9CnZXjU3kD5FHDn2T4bacrDWYtQVSIAisAzPRsGYj4ByHyZjcf
xsdDY1exA1j3PJ7XGEelZMMAutbWdk2LSl7n2uB4G0nL6ONH9l+utlhXVL2SKpjj8uaYNmm7Kkla
eys+VX1I/RPm0fGBb/Wmk6Aa2ho9/kdTkd9i/LIjxqKn46ljQSidhhDwaLsCj+MsYjt/kquP/pQ2
BfrZhXhbR53fDNl55grVKQTg35YKeAw5xX7UpTTFC4kY5uXFCHs8GxyRdpM95LQxD138ktOEDzv+
gMnkhKawZpFg3hCwa/ktf3tnO3AGIcWitr1/Dkq/grji9otaZLXpwMOFurgzyM6/gYiqk2B6ZIie
5nPAeLy0Im74GGtHsg/0ap3HmX1EJD7XDNQicq4FhcZ34VEAIRr66/BeuptD9otnvD3Xgttd/MVr
AjXsdfQ0OBXWJ8bcoSADCkIOhvXpRsy1DFZGpXIn9JLcQaXcHTsBdRgfD3YPm3a5ivdqVAfvXG8g
5JzJh8CcOSTy2P+O++BPa2XIsB7m4+XZKxX765wlvQ9Un0==

==> ZenTaoPMS.pro10.0.rc1.php5.3_5.6.zip: zentaopms/lib/spout/spout.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPsMGt3CBUIK4QYH948xib5itZuQUZeSYGsxkOgFrtyz5xJugscG3anjRziz9Wo+VvfHX/Kw+
kvzk0mCWHwnFGwwVICPu2lORluPZqP7CUDxZybHJmehbC2sOVouQkHgm4PD2SApVcf5GzJgOvL3s
GMTvXVFmC6HzRRkv0plXhp8grVhJrTkKDudDBBGxg8tP8c/Ky4XYrPPV95/ISYQXCOAbyGao1lRa
Y2NagsKpXiwZ7rGnYiPg1FvLqhbR4SeJWLLE6VJOJbqPc/CqTGVc226TTtEIU7b3tl73zvi/MZIK
BuEhRTm/xktrk2Bg46JpcQxMasFx8IgHlHoIDzUR7VLDh2aavu/SkuxcyZ1k9Lg5HX/IyNBdAqjT
jZTcbe/tqmjyKHtdsgUQ9/zGIMW9NbZ7w6cCJrvRY3qNCxQ41+ZP2ZGxyil8BuXeJJAQWsY56Y3w
g5MJ8vTAcUk6WMoLOvD084NujV94pBgJqIUtKPTcG6webFoeyzkbXtS5qQqN3A2z/XGjHvF256W6
GHYQ+ioe7B29OX5XYPOJrclVuvb/vr7VQSGRN3jq9BF7s4ixKsqvwg+IJbjqEKba+a41thk8SsP9
yxoarWRG41Dr9X3dY8/YUnH4WFyo8JBoCKLEZO208aBaQMkcBkwkIWtRtLjIDqzSI0F6T/VdcqPk
Gk79LHJdTtg4yyZUe0RLaT0sDI2ktRyndROWNnvFh4oYpcAwpY7vKmweadcl90==
